@@ -23,8 +23,9 @@
 
 // Qt
 #include <qcursor.h>
-#include <QMenu>
-#include <QMouseEvent>
+#include <qmenu.h>
+#include <qevent.h>
+#include <qregularexpression.h>
 
 // KDE
 #include <klocalizedstring.h>
@@ -48,10 +49,10 @@
  * Creates an empty View. To populate it with MixDevice instances, you must implement
  * initLayout() in your derived class.
  */
-ViewBase::ViewBase(QWidget* parent, const QString &id, Qt::WindowFlags f, ViewBase::ViewFlags vflags, const QString &guiProfileId, KActionCollection *actionColletion)
+ViewBase::ViewBase(QWidget *parent, const QString &id, Qt::WindowFlags f, ViewBase::ViewFlags vflags, const QString &guiProfileId, KActionCollection *actionColletion)
     : QWidget(parent, f),
-      _popMenu(NULL),
-      _actions(actionColletion),
+      _popMenu(nullptr),
+      _applicationActions(actionColletion),
       _vflags(vflags),
       guiLevel(GuiVisibility::Simple),
       _guiProfileId(guiProfileId)
@@ -62,22 +63,13 @@ ViewBase::ViewBase(QWidget* parent, const QString &id, Qt::WindowFlags f, ViewBa
    // When loading the View from the XML profile, guiLevel can get overridden
    m_viewId = id;
    
-   if ( _actions == 0 ) {
-      // We create our own action collection, if the actionColletion was 0.
-      // This is currently done for the ViewDockAreaPopup, but only because it has not been converted to use the app-wide
-      // actionCollection(). This is a @todo.
-      _actions = new KActionCollection( this );
-   }
-   _localActionColletion = new KActionCollection( this );
-
-   // Plug in the "showMenubar" action, if the caller wants it. Typically this is only necessary for views in the KMix main window.
-   if ( vflags & ViewBase::HasMenuBar )
+   if (_applicationActions==nullptr)
    {
-      KToggleAction *m = static_cast<KToggleAction*>(  _actions->action( name(KStandardAction::ShowMenubar) ) ) ;
-      if ( m != 0 ) {
-         bool visible = ( vflags & ViewBase::MenuBarVisible );
-         m->setChecked(visible);
-      }
+      // We create our own action collection, if the actionColletion was NULL.
+      // This is currently done for the ViewDockAreaPopup, but only because it
+      // has not been converted to use the app-wide actionCollection(). This
+      // is a TODO.
+      _applicationActions = new KActionCollection(this);
    }
 }
 
@@ -94,7 +86,7 @@ QPushButton* ViewBase::createConfigureViewButton()
 							   QString(), this);
 	configureViewButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 	configureViewButton->setToolTip(i18n( "Configure this view" ));
-	connect(configureViewButton, SIGNAL(clicked(bool)), SLOT(configureView()));
+	connect(configureViewButton, &QAbstractButton::clicked, this, &ViewBase::configureView);
 	return configureViewButton;
 }
 
@@ -122,11 +114,8 @@ void ViewBase::updateMediaPlaybackIcons()
 	for (int i = 0; i < _mdws.count(); ++i)
 	{
 		// Currently media controls are always attached to sliders => use MDWSlider
-		MDWSlider* mdw = qobject_cast<MDWSlider*>(_mdws[i]);
-		if (mdw != 0)
-		{
-			mdw->updateMediaButton();
-		}
+		MDWSlider *mdw = qobject_cast<MDWSlider*>(_mdws[i]);
+		if (mdw!=nullptr) mdw->updateMediaButton();
 	}
 }
 
@@ -155,16 +144,11 @@ void ViewBase::createDeviceWidgets()
     initLayout();
     for (const shared_ptr<MixDevice> &md : std::as_const(_mixSet))
     {
-        QWidget *mdw = add(md);				// a) Let the implementation do its work
-        _mdws.append(mdw);				// b) Add it to the local list
-        connect(mdw, SIGNAL(guiVisibilityChange(MixDeviceWidget*,bool)), SLOT(guiVisibilitySlot(MixDeviceWidget*,bool)));
-    }
+        QWidget *w = add(md);				// a) Let the implementation do its work
+        _mdws.append(w);				// b) Add it to the local list
 
-    if (!isDynamic())
-    {
-        QAction *action = _localActionColletion->addAction("toggle_channels");
-        action->setText(i18n("Configure Channels..."));
-        connect(action, SIGNAL(triggered(bool)), SLOT(configureView()));
+	MixDeviceWidget *mdw = qobject_cast<MixDeviceWidget *>(w);
+	if (mdw!=nullptr) connect(mdw, &MixDeviceWidget::guiVisibilityChange, this, &ViewBase::guiVisibilitySlot);
     }
 
     constructionFinished();				// allow view to "polish" itself
@@ -217,7 +201,7 @@ void ViewBase::adjustControlsLayout()
 
 	// An old comment in ViewSliders::configurationUpdate() said
 	// that this was necessary for KDE3.  Not sure if it is still
-	// required two generations later.
+	// required more than two generations later.
 	layout()->activate();
 }
 
@@ -263,17 +247,18 @@ QMenu* ViewBase::getPopup()
 
 void ViewBase::popupReset()
 {
-    QAction *act;
+    delete _popMenu;					// recreate the menu from scratch
+    _popMenu = new QMenu(this);
 
-    delete _popMenu;
-    _popMenu = new QMenu( this );
-    _popMenu->addSection( QIcon::fromTheme( QLatin1String(  "kmix" ) ), i18n("Device Settings" ));
+    // This action (set up in the KMixWindow's action collection) is routed
+    // to us when it is triggered, via KMixWindow::slotConfigureCurrentView().
+    // There is therefore no need for a local action here.  Hiding the action
+    // if the current mixer is dynamic is handled by KMixWindow::newMixerShown().
+    QAction *act = _applicationActions->action("toggle_channels_currentview");
+    if (act!=nullptr) _popMenu->addAction(act);
 
-    act = _localActionColletion->action( "toggle_channels" );
-    if ( act ) _popMenu->addAction(act);
-
-    act = _actions->action( "options_show_menubar" );
-    if ( act ) _popMenu->addAction(act);
+    act = _applicationActions->action("options_show_menubar");
+    if (act!=nullptr) _popMenu->addAction(act);
 }
 
 
@@ -358,15 +343,10 @@ void ViewBase::configureView()
     Q_ASSERT( !isDynamic() );
     Q_ASSERT( !pulseaudioPresent() );
     
-    DialogViewConfiguration* dvc = new DialogViewConfiguration(0, *this);
+    DialogViewConfiguration *dvc = new DialogViewConfiguration(nullptr, *this);
     dvc->show();
 }
 
-void ViewBase::toggleMenuBarSlot() {
-    //qCDebug(KMIX_LOG) << "ViewBase::toggleMenuBarSlot() start\n";
-    emit toggleMenuBar();
-    //qCDebug(KMIX_LOG) << "ViewBase::toggleMenuBarSlot() done\n";
-}
 
 /**
  * Loads the configuration of this view.
@@ -397,7 +377,7 @@ void ViewBase::load(const KConfig *config)
 	{
 		const GuiVisibility guiCompl = guiVisibilities[i];
 		bool atLeastOneControlIsShown = false;
-        for (QWidget *qmdw : std::as_const(view->_mdws))
+		for (QWidget *qmdw : std::as_const(view->_mdws))
 		{
 			MixDeviceWidget *mdw = qobject_cast<MixDeviceWidget *>(qmdw);
 			if (mdw!=nullptr)
@@ -418,7 +398,7 @@ void ViewBase::load(const KConfig *config)
 				bool mdwEnabled = false;
 
 				// Consult GuiProfile for visibility
-				mdwEnabled = findMdw(mdw->mixDevice()->id(), guiCompl) != 0; // Match GUI complexity
+				mdwEnabled = findMdw(mdw->mixDevice()->id(), guiCompl)!=nullptr; // Match GUI complexity
 //				qCWarning(KMIX_LOG) << "---------- FIRST RUN: md=" << md->id() << ", guiVisibility=" << guiCompl.getId() << ", enabled=" << mdwEnabled;
 
 				if (mdwEnabled)
@@ -458,8 +438,12 @@ ProfControl *ViewBase::findMdw(const QString& mdwId, GuiVisibility visibility) c
 {
     for (ProfControl *pControl : std::as_const(guiProfile()->getControls()))
 	{
-		QRegExp idRegExp(pControl->id());
-		if ( mdwId.contains(idRegExp) )
+		// TODO: is the pControl->id() really a regular expression?
+		// If not then this is just a simple string match.
+		// See also ViewSliders::initLayout()
+
+		const QRegularExpression idRegExp(pControl->id());
+		if (mdwId.contains(idRegExp))
 		{
 			if (pControl->satisfiesVisibility(visibility))
 			{
