@@ -24,19 +24,50 @@
 #include <QStyleOption>
 #include <QFontMetrics>
 
-VolumeSlider::VolumeSlider(Qt::Orientation orientation, QWidget* parent) : QSlider(orientation, parent)
-,m_orientation(orientation),m_tooltip(new QLabel(parent,Qt::ToolTip))
+VolumeSlider::VolumeSlider(Qt::Orientation orientation, QWidget* parent)
+	: QSlider(orientation, parent)
 {
+	m_orientation = orientation;
+
+	// The 'tooltip' shows the value when the slider is dragged.
+	m_tooltip = new QLabel(parent, Qt::ToolTip);
+	// Set a size large enough to show all values up to 100.
 	QFontMetrics metrics(m_tooltip->font());
-	//Setting a size big enough for all values less than 100
-	QRect labelRect = metrics.boundingRect("88");
-//	m_tooltip->setContentsMargins(3,1,3,1);
+	QRect labelRect = metrics.boundingRect("100");
 	m_tooltip->setMinimumWidth(labelRect.width()+5);
 	m_tooltip->setMinimumHeight(labelRect.height()+3);
 	m_tooltip->setAlignment(Qt::AlignCenter);
-//	m_tooltip->setAlignment(Qt::AlignVCenter);
+
+	// Extra data formerly in 'VolumeSliderExtraData'
+	m_chid = Volume::NOCHANNEL;
+	m_subControlLabel = nullptr;
 }
 
+
+void VolumeSlider::updateToolTip()
+{
+	// The value is a percentage here, but it is not displayed with a "%" suffix due
+	// to size limitations.
+	//
+	// 1) The following operates on the value of one individual channel slider, and thus
+	//    represents only the value of that channel.  This is technically not 100% sound
+	//    for a corner case:  the average of all channels should be displayed in the "joined
+	//    slider mode".  On the other hand, in that "joined slider mode" the slider should
+	//    already represent the average of all channels.  And as soon as you move the slider,
+	//    all channels are changed. So it is likely really exact enough.
+	//
+	// 2) Future directions:  It would be better to do the percentage calculation in the
+	//    Volume class, as it handles corner cases like muting.  But due to "auto-unmuting"
+	//    the value is also correct here.  As the VolumeSlider class currently holds no pointer
+	//    or reference to the "underlying" Volume object, a bit of code "duplication" is
+	//    acceptable here.
+
+	qreal percentReal = (100.0*value())/(maximum()-minimum());
+	int percent = qRound(percentReal);
+	m_tooltip->setText(QString::number(percent));
+}
+
+
 void VolumeSlider::mousePressEvent(QMouseEvent* event)
 {
 	QSlider::mousePressEvent(event);
@@ -56,21 +87,7 @@ void VolumeSlider::mousePressEvent(QMouseEvent* event)
 			m_tooltip->move(mapToGlobal(sliderHandle.topLeft()).x(),mapToGlobal(sliderHandle.topLeft()).y()+height());
 		}
 
-		/**
-		 * 1) The following operates on the value of one individual channel slider, and thus is representing only the
-		 * value of that channel. This is technically not 100% sound for a corner case: The average of all channels
-		 * should be displayed in the "joined slider mode". On the other hand, in "joined slider mode", the slider
-		 * should already represent the average of all channels. And as soon as you move the slider, all channels
-		 * are changed. So it is likely really exact enough.
-		 *
-		 * 2) Future directions: It would be better to do the percentage calculation via the Volume class, as it
-		 * handles corner cases like muting. But due to "auto-unmuting" the value is factually also correct. As the
-		 * VolumeSlider class currently holds no pointer/reference to the "underlying" Volume object, a bit code
-		 * "duplication" is acceptable here.
-		 */
-		qreal percentReal = (100.0*value())/(maximum()-minimum());
-		int percent = qRound(percentReal);
-		m_tooltip->setText(QString::number(percent));
+		updateToolTip();
 		m_tooltip->show();
 	}
 }
@@ -87,34 +104,17 @@ void VolumeSlider::mouseMoveEvent(QMouseEvent* event)
 
 	QStyleOptionSlider opt;
 	initStyleOption(&opt);
-	QRect sliderHandle = style()->subControlRect(QStyle::CC_Slider,&opt,QStyle::SC_SliderHandle,this);
+	const QRect sliderHandle = style()->subControlRect(QStyle::CC_Slider, &opt, QStyle::SC_SliderHandle, this);
 
-	qreal percentReal = (100.0*value())/(maximum()-minimum());
-	int percent = qRound(percentReal);
-
-	//Change width of label if percent becomes 100
-	if (percent == 100)
+	updateToolTip();
+	if (m_orientation==Qt::Vertical)
 	{
-		QFontMetrics metrics(m_tooltip->font());
-		QRect labelRect = metrics.boundingRect("100");
-		m_tooltip->resize(labelRect.width(),m_tooltip->height());
-	}
-	else if(m_tooltip->width() > m_tooltip->minimumWidth())
-	{
-		m_tooltip->resize(m_tooltip->minimumWidth(),m_tooltip->height());
-	}
-	m_tooltip->setText(QString::number(percent));
-
-	if (m_orientation == Qt::Vertical)
-	{
-		m_tooltip->move(mapToGlobal(sliderHandle.topLeft()).x()+width(),mapToGlobal(sliderHandle.topLeft()).y());
+		m_tooltip->move(mapToGlobal(sliderHandle.topLeft()).x()+width(),
+				mapToGlobal(sliderHandle.topLeft()).y());
 	}
 	else
 	{
-		m_tooltip->move(mapToGlobal(sliderHandle.topLeft()).x(),mapToGlobal(sliderHandle.topLeft()).y()+height());
+		m_tooltip->move(mapToGlobal(sliderHandle.topLeft()).x(),
+				mapToGlobal(sliderHandle.topLeft()).y()+height());
 	}
-
-	//qCDebug(KMIX_LOG) << "Position is"<<mapToGlobal(sliderHandle.topLeft()).x()<<","<<mapToGlobal(sliderHandle.topLeft()).y();
-	//qCDebug(KMIX_LOG) << "Volume is "<<percent;
 }
-
